@@ -86,6 +86,17 @@ def plot_scatter(data,x_data, y_data):
     plt.ylabel(f'{y_data}', fontsize=15, fontweight='bold')
     plt.grid()
     
+# fucntion to show regression plots with 95% CI
+# Reference:
+   
+def plot_regplot(data,x_data, y_data):
+
+    plt.figure(figsize=(15,5))
+    sns.regplot(data[x_data], data[y_data], data=data);
+    plt.title(f'{x_data} vs {y_data}', fontsize=15, fontweight='bold')
+    plt.xlabel(f'{x_data}', fontsize=15, fontweight='bold')
+    plt.ylabel(f'{y_data}', fontsize=15, fontweight='bold')
+    plt.grid()
     
 # fucntion to show correlations
 # Reference: https://seaborn.pydata.org/examples/many_pairwise_correlations.html
@@ -232,4 +243,13 @@ def calculating_missing_values(data):
         plt.title('Missing Values')
         plt.show()
     else:
-        print ('No missing values here')
\ No newline at end of file
+        print ('No missing values here')
+        
+        
+        
+        
+        
+        
+# python3 setup.py sdist bdist_wheel
+# twine upload --skip-existing dist/*
+# twine upload dist/*
\ No newline at end of file
